@@ -566,7 +566,7 @@ def container_coverage_reports(config, combine=False):
 
 def test_module(config):
     modules2test = get_modules2test('.', config.get('include'), config.get('exclude'))
-    odoo_test_tags = set(i.strip() for i in (config.get('odoo_test_tags') or '').strip().split(',')) - {''}
+    odoo_test_tags = [i.strip() for i in (config.get('odoo_test_tags') or '').strip().split(',')]
     tags = get_tags(modules2test, odoo_test_tags)
     _logger.debug("module: %s", modules2test)
     extra = ''
